@@ -1,33 +1,46 @@
-import typing
-
 from django.db import models
 
-from drf_spectacular.drainage import warn
+from drf_spectacular.drainage import add_trace_message, get_override, has_override, warn
 from drf_spectacular.extensions import OpenApiFilterExtension
 from drf_spectacular.plumbing import (
-    build_array_type, build_basic_type, build_parameter_type, follow_field_source, get_view_model,
-    is_basic_type,
+    build_array_type, build_basic_type, build_parameter_type, follow_field_source, get_type_hints,
+    get_view_model, is_basic_type,
 )
 from drf_spectacular.types import OpenApiTypes
 from drf_spectacular.utils import OpenApiParameter
 
-# Underspecified filter fields for which heuristics are performed. Serves
-# as an explicit list of all remaining/partially-handled filter fields.
-# ----------------------------------------------------------------------------
-# 'AllValuesFilter',  # for no DB hit skip choices
-# 'AllValuesMultipleFilter',  # for no DB hit skip choices, multi handled
-# 'ChoiceFilter',  # enum handled
-# 'DateRangeFilter',  # TODO not sure how this one works exactly
-# 'LookupChoiceFilter',  # TODO not sure how this one works exactly
-# 'ModelChoiceFilter',  # enum handled
-# 'ModelMultipleChoiceFilter',  # enum,multi handled
-# 'MultipleChoiceFilter',  # enum,multi handled
-# 'RangeFilter',  # min/max handled
-# 'TypedChoiceFilter',  # enum handled
-# 'TypedMultipleChoiceFilter',  # enum,multi handled
-
 
 class DjangoFilterExtension(OpenApiFilterExtension):
+    """
+    Extensions that specifically deals with ``django-filter`` fields. The introspection
+    attempts to estimate the underlying model field types to generate filter types.
+
+    However, there are under-specified filter fields for which heuristics need to be performed.
+    This serves as an explicit list of all partially-handled filter fields:
+
+    - ``AllValuesFilter``: skip choices to prevent DB query
+    - ``AllValuesMultipleFilter``: skip choices to prevent DB query, multi handled though
+    - ``ChoiceFilter``: enum handled, type under-specified
+    - ``DateRangeFilter``: N/A
+    - ``LookupChoiceFilter``: N/A
+    - ``ModelChoiceFilter``: enum handled
+    - ``ModelMultipleChoiceFilter``: enum, multi handled
+    - ``MultipleChoiceFilter``: enum, multi handled
+    - ``RangeFilter``: min/max handled, type under-specified
+    - ``TypedChoiceFilter``: enum handled
+    - ``TypedMultipleChoiceFilter``: enum, multi handled
+
+    In case of warnings or incorrect filter types, you can manually override the underlying
+    field type with a manual ``extend_schema_field`` decoration.
+
+    .. code-block::
+
+        class SomeFilter(FilterSet):
+            some_field = extend_schema_field(OpenApiTypes.NUMBER)(
+                RangeFilter(field_name='some_manually_annotated_field_in_qs')
+            )
+
+    """
     target_class = 'django_filters.rest_framework.DjangoFilterBackend'
 
     def get_schema_operation_parameters(self, auto_schema, *args, **kwargs):
@@ -40,10 +53,11 @@ class DjangoFilterExtension(OpenApiFilterExtension):
             return []
 
         result = []
-        for field_name, filter_field in filterset_class.base_filters.items():
-            result += self.resolve_filter_field(
-                auto_schema, model, filterset_class, field_name, filter_field
-            )
+        with add_trace_message(filterset_class.__name__):
+            for field_name, filter_field in filterset_class.base_filters.items():
+                result += self.resolve_filter_field(
+                    auto_schema, model, filterset_class, field_name, filter_field
+                )
         return result
 
     def resolve_filter_field(self, auto_schema, model, filterset_class, field_name, filter_field):
@@ -64,7 +78,13 @@ class DjangoFilterExtension(OpenApiFilterExtension):
             filters.IsoDateTimeFromToRangeFilter: OpenApiTypes.DATETIME,
             filters.DateTimeFromToRangeFilter: OpenApiTypes.DATETIME,
         }
-        if isinstance(filter_field, tuple(unambiguous_mapping)):
+        if has_override(filter_field, 'field'):
+            annotation = get_override(filter_field, 'field')
+            if is_basic_type(annotation):
+                schema = build_basic_type(annotation)
+            else:
+                schema = annotation
+        elif isinstance(filter_field, tuple(unambiguous_mapping)):
             for cls in filter_field.__class__.__mro__:
                 if cls in unambiguous_mapping:
                     schema = build_basic_type(unambiguous_mapping[cls])
@@ -90,19 +110,21 @@ class DjangoFilterExtension(OpenApiFilterExtension):
             # try to make best effort on the given method
             schema = self._build_filter_method_type(filterset_class, filter_field)
         else:
-            # last resort is to lookup the type via the model field.
-            model_field = self._get_model_field(filter_field, model)
-            if isinstance(model_field, models.Field):
-                try:
-                    schema = auto_schema._map_model_field(model_field, direction=None)
-                except Exception as exc:
-                    warn(
-                        f'Exception raised while trying resolve model field for django-filter '
-                        f'field "{field_name}". Defaulting to string (Exception: {exc})'
-                    )
-                    schema = build_basic_type(OpenApiTypes.STR)
-            else:
-                # default to string if nothing else works
+            try:
+                # the last resort is to lookup the type via the model or queryset field.
+                # first search for the field in the model as this has the least amount of
+                # potential side effects. Only after that fails, attempt to call
+                # get_queryset() to check for potential query annotations.
+                model_field = self._get_model_field(filter_field, model)
+                if not isinstance(model_field, models.Field):
+                    qs = auto_schema.view.get_queryset()
+                    model_field = qs.query.annotations[filter_field.field_name].field
+                schema = auto_schema._map_model_field(model_field, direction=None)
+            except Exception as exc:
+                warn(
+                    f'Exception raised while trying resolve model field for django-filter '
+                    f'field "{field_name}". Defaulting to string (Exception: {exc})'
+                )
                 schema = build_basic_type(OpenApiTypes.STR)
 
         # primary keys are usually non-editable (readOnly=True) and map_model_field correctly
@@ -167,7 +189,7 @@ class DjangoFilterExtension(OpenApiFilterExtension):
             filter_method = getattr(filterset_class, filter_field.method)
 
         try:
-            filter_method_hints = typing.get_type_hints(filter_method)
+            filter_method_hints = get_type_hints(filter_method)
         except:  # noqa: E722
             filter_method_hints = {}
 
@@ -178,4 +200,4 @@ class DjangoFilterExtension(OpenApiFilterExtension):
 
     def _get_model_field(self, filter_field, model):
         path = filter_field.field_name.split('__')
-        return follow_field_source(model, path)
+        return follow_field_source(model, path, emit_warnings=False)
