@@ -240,6 +240,12 @@ class AutoSchema(ViewInspector):
         auths = []
 
         for authenticator in self.view.get_authenticators():
+            if (
+                spectacular_settings.AUTHENTICATION_WHITELIST
+                and authenticator.__class__ not in spectacular_settings.AUTHENTICATION_WHITELIST
+            ):
+                continue
+
             scheme = OpenApiAuthenticationExtension.get_match(authenticator)
             if not scheme:
                 warn(
@@ -661,16 +667,22 @@ class AutoSchema(ViewInspector):
             return append_meta(build_basic_type(OpenApiTypes.STR), meta)
 
         if isinstance(field, serializers.ReadOnlyField):
-            # direct source from the serializer
-            assert field.source_attrs, f'ReadOnlyField "{field}" needs a proper source'
             # when field is nested inside a ListSerializer, the Meta class is 2 steps removed
             if is_list_serializer(field.parent):
-                model = field.parent.parent.Meta.model
+                model = getattr(getattr(field.parent.parent, 'Meta', None), 'model', None)
                 source = field.parent.source_attrs
             else:
-                model = field.parent.Meta.model
+                model = getattr(getattr(field.parent, 'Meta', None), 'model', None)
                 source = field.source_attrs
 
+            if model is None:
+                warn(
+                    f'Could not derive type for ReadOnlyField "{field.field_name}" because the '
+                    f'serializer class has no associated model (Meta class). Consider using some '
+                    f'other field like CharField(read_only=True) instead. defaulting to string.'
+                )
+                return append_meta(build_basic_type(OpenApiTypes.STR), meta)
+
             target = follow_field_source(model, source)
             if callable(target):
                 schema = self._map_response_type_hint(target)
@@ -988,6 +1000,10 @@ class AutoSchema(ViewInspector):
         elif is_basic_type(serializer):
             schema = build_basic_type(serializer)
             request_body_required = False
+        elif isinstance(serializer, dict):
+            # bypass processing and use given schema directly
+            schema = serializer
+            request_body_required = False
         else:
             warn(
                 f'could not resolve request body for {self.method} {self.path}. Defaulting to generic '
