@@ -40,6 +40,8 @@ SPECTACULAR_DEFAULTS: Dict[str, Any] = {
 
     # Dictionary of general configuration to pass to the SwaggerUI({ ... })
     # https://swagger.io/docs/open-source-tools/swagger-ui/usage/configuration/
+    # The settings are serialized with json.dumps(). If you need customized JS, use a
+    # string instead. The string must then contain valid JS and is passed unchanged.
     'SWAGGER_UI_SETTINGS': {
         'deepLinking': True,
     },
@@ -113,6 +115,11 @@ SPECTACULAR_DEFAULTS: Dict[str, Any] = {
     # list responses with ListSerializers/many=True irrespective of the status code.
     'ENABLE_LIST_MECHANICS_ON_NON_2XX': False,
 
+    # Controls which authentication methods are exposed in the schema. If not empty, will hide
+    # authentication classes that are not contained in the whitelist. Use full import paths
+    # like ['rest_framework.authentication.TokenAuthentication', ...]
+    'AUTHENTICATION_WHITELIST': [],
+
     # Option for turning off error and warn messages
     'DISABLE_ERRORS_AND_WARNINGS': False,
 
@@ -161,6 +168,7 @@ IMPORT_STRINGS = [
     'GET_MOCK_REQUEST',
     'SORT_OPERATIONS',
     'SORT_OPERATION_PARAMETERS',
+    'AUTHENTICATION_WHITELIST',
 ]
 
 spectacular_settings = APISettings(
