@@ -2,7 +2,7 @@ const swagger_settings  = {{settings|safe}}
 
 const ui = SwaggerUIBundle({
   url: "{{schema_url|safe}}",
-  dom_id: '#swagger-ui',
+  dom_id: "#swagger-ui",
   presets: [
     SwaggerUIBundle.presets.apis,
   ],
@@ -11,8 +11,12 @@ const ui = SwaggerUIBundle({
   ],
   layout: "BaseLayout",
   requestInterceptor: (request) => {
-    request.headers['X-CSRFToken'] = "{{csrf_token}}"
+    request.headers["X-CSRFToken"] = "{{csrf_token}}"
     return request;
   },
   ...swagger_settings
-})
\ No newline at end of file
+})
+
+{% if oauth2_config %}
+ui.initOAuth({{oauth2_config|safe}})
+{% endif %}
